WavesSearching is the library made to automate the process of finding dispersion relations in equations, systems of equations and their discrete analogs.

The library is an addon of SymPy library, which means that the user will be able to input equations as SymPy expressions and obtain DRs as SymPy expressions to work with them further.

It should be noted that some variables (specifically x, t, h, tau, C, omega, k) are already reserved for the algorithms. Also so far only one type of waves is supported, that is U0 * exp(I * (k*x - w\*t)).

The library is still in development, so it is expected that the functionality will be extended in future.
